import React from 'react';
import styled from 'styled-components';
import defaultTheme, { useTheme } from "../../../theme";
import { Handover } from "../../icons";
/**
 * Progress calculators
 */
var calculateProgressContent = function (content) {
    var borderHexColor = 'blue';
    if (typeof content === 'string') {
        return getIconContent(content);
    }
    var lineHexColor = content.value > 0 && content.value === content.total ? 'blue' : 'secondary';
    return {
        labelContent: getProgressContent(content),
        lineHexColor: lineHexColor,
        borderHexColor: borderHexColor,
    };
};
var calculateProgressCoordinates = function (content) {
    if (!hasProgress(content)) {
        return {};
    }
    var R = 100;
    var alpha = (360 / content.total) * content.value;
    var a = ((90 - alpha) * Math.PI) / 180;
    var x = alpha === 360 ? -0.1 : Math.round(R * Math.cos(a));
    var y = Math.round(-R * Math.sin(a));
    return { x: x, y: y, center: alpha > 180 || x < 0 ? 1 : 0 };
};
var calculateProgressLine = function (content) {
    if (content === 'positive') {
        return { x: -0.1, y: -100, center: 1 };
    }
    return calculateProgressCoordinates(content);
};
var hasProgress = function (content) {
    return typeof content !== 'string' &&
        content.value !== 0 &&
        content.total >= content.value;
};
/**
 * Styled Content
 */
var ProgressBubbleContentContainer = styled.div.withConfig({ displayName: "ProgressBubbleContentContainer", componentId: "sc-3rgfb8" })({
    display: 'flex',
    height: '100%',
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: 'space-between',
    padding: '10px 0',
});
var ProgressBubbleText = styled.span.withConfig({ displayName: "ProgressBubbleText", componentId: "sc-f1d3li" })({
    fontSize: '10px',
    lineHeight: '5px',
});
var ProgressBubbleBorder = styled.span.withConfig({ displayName: "ProgressBubbleBorder", componentId: "sc-95x83x" })({
    display: 'block',
    width: '20px',
    borderTop: '1px solid #f5f5f5',
});
var getProgressContent = function (content) { return (React.createElement(ProgressBubbleContentContainer, null,
    React.createElement(ProgressBubbleText, null, content.value),
    React.createElement(ProgressBubbleBorder, null),
    React.createElement(ProgressBubbleText, null, content.total))); };
var getIconColors = function (status) {
    switch (status) {
        case 'positive':
            return { lineColor: 'primary', iconColor: 'blue' };
        case 'conversionStarted':
            return { lineColor: 'blue', iconColor: 'blue' };
        default:
            return { lineColor: 'secondary', iconColor: 'primary' };
    }
};
var getIconContent = function (status) {
    var _a = getIconColors(status), iconColor = _a.iconColor, lineColor = _a.lineColor;
    var labelContent = React.createElement(Handover, { color: iconColor });
    return {
        labelContent: labelContent,
        lineHexColor: lineColor,
        borderHexColor: iconColor,
    };
};
var ProgressLine = styled.div.withConfig({ displayName: "ProgressLine", componentId: "sc-1a1ghiq" })({
    width: '100%',
    height: '4px',
}, function (_a) {
    var theme = _a.theme, color = _a.color;
    return color
        ? {
            background: theme.colors[color].default,
        }
        : null;
});
ProgressLine.defaultProps = {
    theme: defaultTheme,
};
var ProgressBubbleLabel = styled.div.withConfig({ displayName: "ProgressBubbleLabel", componentId: "sc-y2uzuw" })({
    position: 'relative',
    width: '45px',
    height: '45px',
    margin: '0 !important',
    lineHeight: '20px',
    borderRadius: '50%',
}, function (_a) {
    var theme = _a.theme;
    return ({ backgroundColor: theme.greyscale.light });
});
ProgressBubbleLabel.defaultProps = {
    theme: defaultTheme,
};
var ProgressIndicator = styled.svg.withConfig({ displayName: "ProgressIndicator", componentId: "sc-99p1qc" })({
    position: 'absolute',
    top: '2px',
    left: 0,
});
var ProgressBubble = styled.div.withConfig({ displayName: "ProgressBubble", componentId: "sc-17n1owz" })({
    position: 'relative',
    display: 'flex',
    width: '45px',
    flexFlow: 'column nowrap',
    flexShrink: 0,
    alignItems: 'center',
    justifyContent: 'center',
    padding: '2px',
    textAlign: 'center',
});
/**
 * Progress Bubble
 */
export var ProgressBubbleContent = function (_a) {
    var content = _a.content, showLine = _a.showLine, label = _a.label;
    var _b = calculateProgressContent(content), labelContent = _b.labelContent, lineHexColor = _b.lineHexColor, borderHexColor = _b.borderHexColor;
    var showProgressIndicator = hasProgress(content) && label !== 'Handover';
    var _c = calculateProgressLine(content), x = _c.x, y = _c.y, center = _c.center;
    var colors = useTheme().colors;
    return (React.createElement(React.Fragment, null,
        React.createElement(ProgressBubble, null,
            React.createElement(ProgressBubbleLabel, null, labelContent),
            showProgressIndicator && (React.createElement(ProgressIndicator, { viewBox: "-106 -106 212 212" },
                React.createElement("path", { d: "M 0,-100 A 100,100 0 " + (center || 0) + ",1 " + (x || 0) + "," + (y || 0), fill: "none", strokeWidth: "12", stroke: colors[borderHexColor].default })))),
        showLine && React.createElement(ProgressLine, { color: lineHexColor })));
};
