var getBreakpoint = function (theme, value) {
    return typeof value === 'number' ? value : theme.breakpoints[value];
};
/**
 * Any screen width up to the selected breakpoint
 * @param bp Select breakpoint to go up to
 */
export var above = function (bp) { return function (_a) {
    var theme = _a.theme;
    return "@media only screen and (min-width: " + getBreakpoint(theme, bp) + "px)";
}; };
/**
 * Any screen width down to the selected breakpoint
 * @param bp Select breakpoint to go down to
 */
export var below = function (bp) { return function (_a) {
    var theme = _a.theme;
    return "@media only screen and (max-width: " + (getBreakpoint(theme, bp) - 0.02) + "px)";
}; };
/**
 * Any screen width between the selected breakpoints
 * @param a Select start breakpoint
 * @param b Select end breakpoint to go up to
 */
export var between = function (min, max) { return function (_a) {
    var theme = _a.theme;
    return "@media only screen and (min-width: " + getBreakpoint(theme, min) + "px) and (max-width: " + (getBreakpoint(theme, max) - 0.02) + "px)";
}; };
/**
 * Any screen size between medium
 */
export var sm = below('md');
/**
 * Any screen size between medium and large
 */
export var md = between('md', 'lg');
/**
 * Any screen size between large and extra large
 */
export var lg = between('lg', 'xl');
/**
 * Any screen size above extra large
 */
export var xl = above('xl');
